@@ -9,13 +9,13 @@ that is found in the LICENSE file
 '''
 import os, fnmatch
 from types import *
-from ConfigParser import *
+#from ConfigParser import *
 import pickle
 from datetime import date
 import numpy as np
 from scipy import interpolate
-from FortranFormat import *
-import _chianti_constants as const
+from .FortranFormat import *
+from . import _chianti_constants as const
 #
 #
 def between(array,limits):
@@ -470,7 +470,7 @@ def elvlcRead(ions, filename = None, verbose=0,  useTh=1):
         bname = os.path.basename(filename)
         ions = bname.split('.')[0]
     if not os.path.isfile(elvlname):
-        print ' elvlc file does not exist:  ',elvlname
+        print(' elvlc file does not exist:  ',elvlname)
         return {'status':0}
     status = 1
     input=open(elvlname,'r')
@@ -485,7 +485,7 @@ def elvlcRead(ions, filename = None, verbose=0,  useTh=1):
         nlvls=nlvls+1
     nlvls-=1
     if verbose:
-        print ' nlvls = ', nlvls
+        print(' nlvls = ', nlvls)
     lvl=[0]*nlvls
     conf=[0]*nlvls
     term=[0]*nlvls
@@ -501,7 +501,7 @@ def elvlcRead(ions, filename = None, verbose=0,  useTh=1):
     pretty=[0]*nlvls
     for i in range(0,nlvls):
         if verbose:
-            print s1[i][0:115]
+            print(s1[i][0:115])
         inpt=FortranLine(s1[i][0:115],elvlcFormat)
         lvl[i]=inpt[0]
         conf[i]=inpt[1]
@@ -549,7 +549,7 @@ def elvlcWrite(info):
     ref, the references in the literature to the data in the input info'''
     gname = info['ionS']
     elvlcname = gname + '.elvlc'
-    print ' elvlc file name = ', elvlcname
+    print(' elvlc file name = ', elvlcname)
     out = open(elvlcname, 'w')
     for i,  conf in enumerate(info['conf']):
         mult = int(2.*info['j'][i]+1.)
@@ -1080,75 +1080,6 @@ def dilute(radius):
     #
     # ------------------------------------------------------------------------------
     #
-def diCross(diParams, energy=0, verbose=0):
-    '''
-    Calculate the direct ionization cross section.
-    diParams obtained by util.diRead with the following keys:
-    ['info', 'ysplom', 'xsplom', 'btf', 'ev1', 'ref', 'eaev']
-    Given as a function of the incident electron energy in eV
-    returns a dictionary - {'energy':energy, 'cross':cross}
-    '''
-    iso=diParams['info']['iz'] - diParams['info']['ion'] + 1
-    energy = np.array(energy, 'float64')
-    if not energy.any():
-        btenergy=0.1*np.arange(10)
-        btenergy[0]=0.01
-        dum=np.ones(len(btenergy))
-        [energy, dum] = descale_bti(btenergy, dum, 2., diParams['ev1'][0])
-        energy=np.asarray(energy, 'float64')
-    #
-    if iso == 1 and self.Z >= 6:
-        #  hydrogenic sequence
-        ryd=27.2113845/2.
-        u=energy/self.Ip
-        ev1ryd=self.Ip/ryd
-        a0=0.5291772108e-8
-        a_bohr=const.pi*a0**2   # area of bohr orbit
-        if self.Z >= 20:
-            ff = (140.+(self.Z/20.)**3.2)/141.
-        else:
-            ff = 1.
-        qr = util.qrp(self.Z,u)*ff
-        bb = 1.  # hydrogenic
-        qh = bb*a_bohr*qr/ev1ryd**2
-        diCross = {'energy':energy, 'cross':qh}
-    elif iso == 2 and self.Z >= 10:
-        #  use
-        ryd=27.2113845/2.
-        u=energy/self.Ip
-        ev1ryd=self.Ip/ryd
-        a0=0.5291772108e-8
-        a_bohr=const.pi*a0**2   # area of bohr orbit
-        if self.Z >= 20:
-            ff=(140.+(self.Z/20.)**3.2)/141.
-        else:
-            ff=1.
-        qr=util.qrp(self.Z,u)*ff
-        bb=2.  # helium-like
-        qh=bb*a_bohr*qr/ev1ryd**2
-        diCross={'energy':energy, 'cross':qh}
-    else:
-        cross=np.zeros(len(energy), 'Float64')
-
-        for ifac in range(diParams['info']['nfac']):
-            # prob. better to do this with masked arrays
-            goode=energy > diParams['ev1'][ifac]
-            if goode.sum() > 0:
-                dum=np.ones(len(energy))
-                btenergy, btdum = scale_bti(energy[goode],dum[goode], diParams['btf'][ifac], diParams['ev1'][ifac])
-                # these interpolations were made with the scipy routine used here
-                y2=interpolate.splrep(diParams['xsplom'][ifac], diParams['ysplom'][ifac], s=0)
-                btcross=interpolate.splev(btenergy, y2, der=0)
-                energy1, cross1 = descale_bti(btenergy, btcross, diParams['btf'][ifac], diParams['ev1'][ifac] )
-                offset=len(energy)-goode.sum()
-                if verbose:
-                    pl.plot(diParams['xsplom'][ifac], diParams['ysplom'][ifac])
-                    pl.plot(btenergy, btcross)
-                if offset > 0:
-                    seq=[np.zeros(offset, 'Float64'), cross1]
-                    cross1=np.hstack(seq)
-                cross+=cross1*1.e-14
-        return {'energy':energy, 'cross':cross}
     #
     #-----------------------------------------------------------
     #
@@ -1272,7 +1203,7 @@ def eaRead(ions, filename=0):
         splupsname=fname+'.easplups'
     if not os.path.exists(splupsname):
         print((' could not find file:  ', splupsname))
-        self.Splups={"lvl1":-1}
+        Splups={"lvl1":-1}
         return {"lvl1":-1}
     # there is splups/psplups data
     else:
