@@ -2,7 +2,7 @@ import numpy as np
 import pyneb as pn
 
 ELEM_LIST = ['Ag', 'Al', 'Ar', 'Au', 'B', 'Ba', 'C', 'Ca', 'Cl', 'Co', 'Cr', 'Cu', 'F', 'Fe', 'H', 'He', 'K',
-             'Kr', 'Mg', 'N', 'Na', 'Ne', 'Ni', 'O', 'P', 'S', 'Si', 'Xe', 'Zn', 'Se', 'Br', 'Rb', '3He']
+             'Kr', 'Mg', 'Mn', 'N', 'Na', 'Ne', 'Ni', 'O', 'P', 'S', 'Si', 'Ti', 'Xe', 'Zn', 'Se', 'Br', 'Rb', '3He']
 SPEC_LIST = ['1', '2', '3', '4', '5', '6', '7']
 
 def _print_LINE_LABEL_LIST(*args, **kwargs):
@@ -58,6 +58,7 @@ LINE_LABEL_LIST['C2'] = ['2325A', '2328A', '2323A', '2327A', '2322A', '2325A', '
                          '198.8m', '353.3m', '3967.2m']
 LINE_LABEL_LIST['C3'] = ['1910A', '1909A', '1907A', '977A', '2000A', '2001A', '2003A', '422.0m', '124.9m', '177.4m']
 LINE_LABEL_LIST['C4'] = ['1551A', '1548A', '92.8m']
+LINE_LABEL_LIST['Ca2'] = ['7292A', '7324A']
 LINE_LABEL_LIST['Ca5'] = ['5309A', '6087A', '6428A', '2280A', '2413A', '2464A', '3998A', '4.16m', '3.05m', '11.5m']
 LINE_LABEL_LIST['Cl2'] = ['8579A', '9124A', '9381A', '3586A', '3678A', '3719A', '6162A', '14.4m', '10.0m', '33.3m']
 LINE_LABEL_LIST['Cl3'] = ['5538A', '5518A', '3353A', '8500A', '8548A', '3343A', '8434A', '8481A', '151.5m', '108.0m']
@@ -73,6 +74,7 @@ LINE_LABEL_LIST['Fe6'] = ['3556A', '3929A', '5146A', '5176A', '5278A', '5335A',
 LINE_LABEL_LIST['Fe7'] = ['5159A', '5276A', '5721A', '6087A']
 LINE_LABEL_LIST['K4'] = ['6102A', '6796A', '7109A', '2594A', '2711A', '2760A', '4511A', '6.0m', '4.3m', '15.4m']
 LINE_LABEL_LIST['K5'] = ['4163A', '4123A', '2514A', '6349A', '6446A', '2495A', '6222A', '6316A', '42.2m', '31.0m']
+LINE_LABEL_LIST['K6'] = ['5602A', '6229A']
 LINE_LABEL_LIST['Kr3'] = ['6827A', '9902A', '3022A', '3504A', '3600A', '5423A', '2.2m', '1.88m', '13.1m', '1.07m']
 LINE_LABEL_LIST['Kr4'] = ['5868A', '5346A', '3219A', '7131A', '8091A', '2993A', '6108A', '6798A', '6.0m', '4.26m']
 LINE_LABEL_LIST['Kr5'] = ['5069A', '6256A', '8243A', '2550A', '2819A', '3163A', '5132A', '2.67m', '1.32m', '2.6m']
@@ -87,6 +89,7 @@ LINE_LABEL_LIST['N3'] = ['1749A', '1754A', '1747A', '1752A', '1744A', '1750A', '
                          '2288A', '2280A', '2283A', '2287A', '763A', '764A', '1356A', '1357A', '3334A', 
                          '3335A', '57.4m', '167.5m', '71.0m', '123.3m', '1492.1m']
 LINE_LABEL_LIST['N4'] = ['1488A', '1487A', '1483A', '765A', '1575A', '1576A', '1580A', '158.4m', '48.3m', '69.4m']
+LINE_LABEL_LIST['Na3'] = ['7.3m']
 LINE_LABEL_LIST['Na4'] = ['3242A', '3362A', '3416A', '1504A', '1529A', '1540A', '2804A', '9.0m', '6.34m', '21.3m']
 LINE_LABEL_LIST['Na6'] = ['2816A', '2872A', '2972A', '1343A', '1356A', '1378A', '2569A', '14.39m', '5.4m', '8.6m']
 LINE_LABEL_LIST['Ne2'] = ['12.8m']
@@ -126,6 +129,9 @@ LINE_LABEL_LIST['Xe4'] = ['7535A', '5709A', '3566A', '6769A', '9498A', '2804A',
 LINE_LABEL_LIST['Xe6'] = ['6409A']
 
 
+
+
+
 OLD_LINE_LABEL_LIST = {}
 OLD_LINE_LABEL_LIST['H1'] = ['3750A', '3771A', '3889A', '4102A', '4340A', '4861A', '6563A', '9015A', '9229A']
 OLD_LINE_LABEL_LIST['He1'] = ['5876A', '2945A', '3188A', '3614A', '3889A', '3965A', '4026A', '4121A', '4388A',
